==> node-rollup_0.68.2.orig.tar.gz: rollup-0.68.2/test/form/samples/large-var-cnt-deduping/_expected.js <==
var x = "a";

var result = `1 = ${x}`;

var x$1 = "b";

var result$1 = `2 = ${x$1}`;

var x$2 = "c";

var result$2 = `3 = ${x$2}`;

var x$3 = "d";

var result$3 = `4 = ${x$3}`;

var x$4 = "e";

var result$4 = `5 = ${x$4}`;

var x$5 = "f";

var result$5 = `6 = ${x$5}`;

var x$6 = "g";

var result$6 = `7 = ${x$6}`;

var x$7 = "h";

var result$7 = `8 = ${x$7}`;

var x$8 = "i";

var result$8 = `9 = ${x$8}`;

var x$9 = "j";

var result$9 = `10 = ${x$9}`;

var x$a = "k";

var result$a = `11 = ${x$a}`;

var x$b = "l";

var result$b = `12 = ${x$b}`;

var x$c = "m";

var result$c = `13 = ${x$c}`;

var x$d = "n";

var result$d = `14 = ${x$d}`;

var x$e = "o";

var result$e = `15 = ${x$e}`;

var x$f = "p";

var result$f = `16 = ${x$f}`;

var x$g = "q";

var result$g = `17 = ${x$g}`;

var x$h = "r";

var result$h = `18 = ${x$h}`;

var x$i = "s";

var result$i = `19 = ${x$i}`;

var x$j = "t";

var result$j = `20 = ${x$j}`;

var x$k = "u";

var result$k = `21 = ${x$k}`;

var x$l = "v";

var result$l = `22 = ${x$l}`;

var x$m = "w";

var result$m = `23 = ${x$m}`;

var x$n = "x";

var result$n = `24 = ${x$n}`;

var x$o = "y";

var result$o = `25 = ${x$o}`;

var x$p = "z";

var result$p = `26 = ${x$p}`;

var x$q = "A";

var result$q = `27 = ${x$q}`;

var x$r = "B";

var result$r = `28 = ${x$r}`;

var x$s = "C";

var result$s = `29 = ${x$s}`;

var x$t = "D";

var result$t = `30 = ${x$t}`;

var x$u = "E";

var result$u = `31 = ${x$u}`;

var x$v = "F";

var result$v = `32 = ${x$v}`;

var x$w = "G";

var result$w = `33 = ${x$w}`;

var x$x = "H";

var result$x = `34 = ${x$x}`;

var x$y = "I";

var result$y = `35 = ${x$y}`;

var x$z = "J";

var result$z = `36 = ${x$z}`;

var x$A = "K";

var result$A = `37 = ${x$A}`;

var x$B = "L";

var result$B = `38 = ${x$B}`;

var x$C = "M";

var result$C = `39 = ${x$C}`;

var x$D = "N";

var result$D = `40 = ${x$D}`;

var x$E = "O";

var result$E = `41 = ${x$E}`;

var x$F = "P";

var result$F = `42 = ${x$F}`;

var x$G = "Q";

var result$G = `43 = ${x$G}`;

var x$H = "R";

var result$H = `44 = ${x$H}`;

var x$I = "S";

var result$I = `45 = ${x$I}`;

var x$J = "T";

var result$J = `46 = ${x$J}`;

var x$K = "U";

var result$K = `47 = ${x$K}`;

var x$L = "V";

var result$L = `48 = ${x$L}`;

var x$M = "W";

var result$M = `49 = ${x$M}`;

var x$N = "X";

var result$N = `50 = ${x$N}`;

var x$O = "Y";

var result$O = `51 = ${x$O}`;

var x$P = "Z";

var result$P = `52 = ${x$P}`;

var x$Q = "1";

var result$Q = `53 = ${x$Q}`;

var x$R = "2";

var result$R = `54 = ${x$R}`;

var x$S = "3";

var result$S = `55 = ${x$S}`;

var x$T = "4";

var result$T = `56 = ${x$T}`;

var x$U = "5";

var result$U = `57 = ${x$U}`;

var x$V = "6";

var result$V = `58 = ${x$V}`;

var x$W = "7";

var result$W = `59 = ${x$W}`;

var x$X = "8";

var result$X = `60 = ${x$X}`;

var x$Y = "9";

var result$Y = `61 = ${x$Y}`;

var x$Z = "0";

var result$Z = `62 = ${x$Z}`;

var x$_ = "_";

var result$_ = `63 = ${x$_}`;

var x$10 = "0";

var result$10 = `64 = ${x$10}`;

var results = [result,
result$1,
result$2,
result$3,
result$4,
result$5,
result$6,
result$7,
result$8,
result$9,
result$a,
result$b,
result$c,
result$d,
result$e,
result$f,
result$g,
result$h,
result$i,
result$j,
result$k,
result$l,
result$m,
result$n,
result$o,
result$p,
result$q,
result$r,
result$s,
result$t,
result$u,
result$v,
result$w,
result$x,
result$y,
result$z,
result$A,
result$B,
result$C,
result$D,
result$E,
result$F,
result$G,
result$H,
result$I,
result$J,
result$K,
result$L,
result$M,
result$N,
result$O,
result$P,
result$Q,
result$R,
result$S,
result$T,
result$U,
result$V,
result$W,
result$X,
result$Y,
result$Z,
result$_,
result$10
];

results.forEach( ( result$$1 ) => {
    console.log( result$$1 );
} );

==> node-rollup_2.38.4.orig.tar.gz: rollup-2.38.4/test/form/samples/large-var-cnt-deduping/_expected.js <==
var x = "a";

var result = `1 = ${x}`;

var x$1 = "b";

var result$1 = `2 = ${x$1}`;

var x$2 = "c";

var result$2 = `3 = ${x$2}`;

var x$3 = "d";

var result$3 = `4 = ${x$3}`;

var x$4 = "e";

var result$4 = `5 = ${x$4}`;

var x$5 = "f";

var result$5 = `6 = ${x$5}`;

var x$6 = "g";

var result$6 = `7 = ${x$6}`;

var x$7 = "h";

var result$7 = `8 = ${x$7}`;

var x$8 = "i";

var result$8 = `9 = ${x$8}`;

var x$9 = "j";

var result$9 = `10 = ${x$9}`;

var x$a = "k";

var result$a = `11 = ${x$a}`;

var x$b = "l";

var result$b = `12 = ${x$b}`;

var x$c = "m";

var result$c = `13 = ${x$c}`;

var x$d = "n";

var result$d = `14 = ${x$d}`;

var x$e = "o";

var result$e = `15 = ${x$e}`;

var x$f = "p";

var result$f = `16 = ${x$f}`;

var x$g = "q";

var result$g = `17 = ${x$g}`;

var x$h = "r";

var result$h = `18 = ${x$h}`;

var x$i = "s";

var result$i = `19 = ${x$i}`;

var x$j = "t";

var result$j = `20 = ${x$j}`;

var x$k = "u";

var result$k = `21 = ${x$k}`;

var x$l = "v";

var result$l = `22 = ${x$l}`;

var x$m = "w";

var result$m = `23 = ${x$m}`;

var x$n = "x";

var result$n = `24 = ${x$n}`;

var x$o = "y";

var result$o = `25 = ${x$o}`;

var x$p = "z";

var result$p = `26 = ${x$p}`;

var x$q = "A";

var result$q = `27 = ${x$q}`;

var x$r = "B";

var result$r = `28 = ${x$r}`;

var x$s = "C";

var result$s = `29 = ${x$s}`;

var x$t = "D";

var result$t = `30 = ${x$t}`;

var x$u = "E";

var result$u = `31 = ${x$u}`;

var x$v = "F";

var result$v = `32 = ${x$v}`;

var x$w = "G";

var result$w = `33 = ${x$w}`;

var x$x = "H";

var result$x = `34 = ${x$x}`;

var x$y = "I";

var result$y = `35 = ${x$y}`;

var x$z = "J";

var result$z = `36 = ${x$z}`;

var x$A = "K";

var result$A = `37 = ${x$A}`;

var x$B = "L";

var result$B = `38 = ${x$B}`;

var x$C = "M";

var result$C = `39 = ${x$C}`;

var x$D = "N";

var result$D = `40 = ${x$D}`;

var x$E = "O";

var result$E = `41 = ${x$E}`;

var x$F = "P";

var result$F = `42 = ${x$F}`;

var x$G = "Q";

var result$G = `43 = ${x$G}`;

var x$H = "R";

var result$H = `44 = ${x$H}`;

var x$I = "S";

var result$I = `45 = ${x$I}`;

var x$J = "T";

var result$J = `46 = ${x$J}`;

var x$K = "U";

var result$K = `47 = ${x$K}`;

var x$L = "V";

var result$L = `48 = ${x$L}`;

var x$M = "W";

var result$M = `49 = ${x$M}`;

var x$N = "X";

var result$N = `50 = ${x$N}`;

var x$O = "Y";

var result$O = `51 = ${x$O}`;

var x$P = "Z";

var result$P = `52 = ${x$P}`;

var x$Q = "1";

var result$Q = `53 = ${x$Q}`;

var x$R = "2";

var result$R = `54 = ${x$R}`;

var x$S = "3";

var result$S = `55 = ${x$S}`;

var x$T = "4";

var result$T = `56 = ${x$T}`;

var x$U = "5";

var result$U = `57 = ${x$U}`;

var x$V = "6";

var result$V = `58 = ${x$V}`;

var x$W = "7";

var result$W = `59 = ${x$W}`;

var x$X = "8";

var result$X = `60 = ${x$X}`;

var x$Y = "9";

var result$Y = `61 = ${x$Y}`;

var x$Z = "0";

var result$Z = `62 = ${x$Z}`;

var x$_ = "_";

var result$_ = `63 = ${x$_}`;

var x$$ = "$";

var result$$ = `64 = ${x$$}`;

var x$10 = "0";

var result$10 = `65 = ${x$10}`;

var results = [result,
result$1,
result$2,
result$3,
result$4,
result$5,
result$6,
result$7,
result$8,
result$9,
result$a,
result$b,
result$c,
result$d,
result$e,
result$f,
result$g,
result$h,
result$i,
result$j,
result$k,
result$l,
result$m,
result$n,
result$o,
result$p,
result$q,
result$r,
result$s,
result$t,
result$u,
result$v,
result$w,
result$x,
result$y,
result$z,
result$A,
result$B,
result$C,
result$D,
result$E,
result$F,
result$G,
result$H,
result$I,
result$J,
result$K,
result$L,
result$M,
result$N,
result$O,
result$P,
result$Q,
result$R,
result$S,
result$T,
result$U,
result$V,
result$W,
result$X,
result$Y,
result$Z,
result$_,
result$$,
result$10
];

console.log(results);
